@@ -23,11 +23,6 @@ class UARTService(Service):
     """
     Provide UART-like functionality via the Nordic NUS service.
 
-    :param int timeout:  the timeout in seconds to wait
-      for the first character and between subsequent characters.
-    :param int buffer_size: buffer up to this many bytes.
-      If more bytes are received, older bytes will be discarded.
-
     See ``examples/ble_uart_echo_test.py`` for a usage example.
     """
 
